This function takes a list, sees if it has an element named 'content' and
then checks if content contains an element named obj_type: if it does
not contain an element as passed in obj_type this function adds it,
otherwise it leaves the list obj untouched. The contents of 'content'
are set as value of <obj>$content$<obj_type>.
add_object_tier(obj, obj_type)A list containing the <obj>$content$<obj_type>, whose value is
either NULL if it had not any value before or the value of
<obj>$content.
A list.
A non-empty string.