powered by
Get all child terms of this trait in the EFO hierarchy
get_child_efo( efo_id, verbose = FALSE, warnings = TRUE, page_size = 20L, progress_bar = TRUE )
A named list whose values are character vectors of EFO identifiers.
A character vector of EFO identifiers.
A logical indicating whether the function should be verbose about the different queries or not.
logical
A logical indicating whether to print warnings, if any.
An integer scalar indicating the page value to be used in the JSON requests, can be between 1 and 1000.
integer
1
1000
Whether to show a progress bar as the paginated resources are retrieved.
if (FALSE) { get_child_efo(c('EFO_0004884', 'EFO_0004343', 'EFO_0005299')) }
Run the code above in your browser using DataLab