This function checks the value of TEST_FAST, if it is 'true' it skips
the test otherwise it still runs the following expectations. Please note that
this function is to be used in gwasrapidd development.
skip_if_testing_is_fast()Returns TRUE if the environment variable 'TEST_FAST' is
set to 'false', or does not return anything but triggers the side
effect of skipping the next test (with testthat).